==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>S&apos;ha esgotat el temps d&apos;espera de l&apos;autenticació.</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>El disc està ocupat. No es pot desmuntar ara.</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>El disc està ocupat. No es pot extreure ara.</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>El dispositiu està ocupat. No es pot extreure ara.</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>El dispositiu està ocupat. No es pot suprimir ara.</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>Volum: %1</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Desconegut</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>El dispositiu no s&apos;ha extret amb seguretat.</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>A la propera, cliqueu a &quot;Extreu-lo amb seguretat&quot; i després desconnecteu-lo.</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">El dispositiu està ocupat. No es pot extreure ara.</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">El dispositiu està ocupat. No es pot suprimir ara.</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>No es pot desmuntar el dispositiu.</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>El disc està muntat per l&apos;usuari %1, no podeu desmuntar-lo.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>No es pot trobar el dispositiu muntat.</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Discs</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disc</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Extreu-ho tot</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>El dispositiu s&apos;ha extret amb seguretat.</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Accés denegat</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>No teniu permís per accedir a aquesta carpeta.</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>S&apos;escaneja el dispositiu. Voleu interrompre-ho?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Interromp</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.6.4.orig.tar.xz: dde-file-manager-5.6.4/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>S&apos;ha esgotat el temps d&apos;espera de l&apos;autenticació.</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>El disc està ocupat. No es pot desmuntar ara.</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>El disc està ocupat. No es pot extreure ara.</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>El dispositiu està ocupat. No es pot extreure ara.</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>El dispositiu està ocupat. No es pot suprimir ara.</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>Volum: %1</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Desconegut</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>El dispositiu no s&apos;ha extret amb seguretat.</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>A la propera, cliqueu a &quot;Extreu-lo amb seguretat&quot; i després desconnecteu-lo.</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>No es pot desmuntar el dispositiu.</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>El disc està muntat per l&apos;usuari %1, no podeu desmuntar-lo.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>No es pot trobar el dispositiu muntat.</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Discs</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disc</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Extreu-ho tot</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>El dispositiu s&apos;ha extret amb seguretat.</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Accés denegat</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>No teniu permís per accedir a aquesta carpeta.</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>S&apos;escaneja el dispositiu. Voleu interrompre-ho?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Interromp</translation>
    </message>
</context>
</TS>
